unofficial mirror of meta@public-inbox.org
 help / color / mirror / Atom feed
From: Eric Wong <e@80x24.org>
To: meta@public-inbox.org
Subject: [PATCH] extsearchidx: symlink .rev and .bitmap files into ALL.git
Date: Wed, 30 Jun 2021 19:14:48 +0000	[thread overview]
Message-ID: <20210630191448.20714-1-e@80x24.org> (raw)

It's possible for these to exist and git can (or may eventually)
take advantage of them to speed up functionality which affects
us.
---
 lib/PublicInbox/ExtSearchIdx.pm | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/lib/PublicInbox/ExtSearchIdx.pm b/lib/PublicInbox/ExtSearchIdx.pm
index a14f0652..e4eaf5be 100644
--- a/lib/PublicInbox/ExtSearchIdx.pm
+++ b/lib/PublicInbox/ExtSearchIdx.pm
@@ -943,9 +943,9 @@ sub symlink_packs ($$) {
 				symlink($idx, "$dst.idx") and
 				-f $idx) {
 			++$ret;
 			# .promisor and .keep are optional
 			# XXX should we symlink .keep here?
-			for my $s (qw(promisor)) {
+			for my $s (qw(promisor bitmap rev)) {
 				symlink("$src.$s", "$dst.$s") if -f "$src.$s";
 			}
 		} elsif (!$!{EEXIST}) {
@@ -1018,7 +1018,7 @@ sub idx_init { # similar to V2Writable
 	if (!mkdir($pd) && $!{EEXIST} && opendir($dh, $pd)) {
 		# drop stale symlinks
 		while (defined(my $dn = readdir($dh))) {
-			if ($dn =~ /\.(?:idx|pack|promisor)\z/) {
+			if ($dn =~ /\.(?:idx|pack|promisor|bitmap|rev)\z/) {
 				my $f = "$pd/$dn";
 				unlink($f) if -l $f && !-e $f;
 			}
@@ -943,9 +943,9 @@ sub symlink_packs ($$) {
 				-f $idx) {
 			++$ret;
-			# .promisor and .keep are optional
+			# .promisor, .bitmap, .rev and .keep are optional
 			# XXX should we symlink .keep here?

                 reply	other threads:[~2021-06-30 19:14 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

  List information: https://public-inbox.org/README

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20210630191448.20714-1-e@80x24.org \
    --to=e@80x24.org \
    --cc=meta@public-inbox.org \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).